@@ -1,7 +1,7 @@
 /*
    dcraw.h - Dave Coffin's raw photo decoder - header for C++ adaptation
-   Copyright 1997-2006 by Dave Coffin, dcoffin a cybercom o net
-   Copyright 2004-2006 by Udi Fuchs, udifuchs a gmail o com
+   Copyright 1997-2007 by Dave Coffin, dcoffin a cybercom o net
+   Copyright 2004-2007 by Udi Fuchs, udifuchs a gmail o com
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
@@ -24,7 +24,7 @@ class DCRaw { public:
 /* All dcraw's global variables are members of this class. */
 FILE *ifp;
 short order;
-char *ifname, make[64], model[72], model2[64], *meta_data, cdesc[5];
+char *ifname, make[64], model[64], model2[64], *meta_data, cdesc[5];
 float flash_used, canon_ev, iso_speed, shutter, aperture, focal_len;
 time_t timestamp;
 unsigned shot_order, kodak_cbpp, filters, unique_id, *oprof;
@@ -34,15 +34,16 @@ int thumb_offset, thumb_length, thumb_width, thumb_height, thumb_misc;
 int tiff_nifds, tiff_flip, tiff_bps, tiff_compress, tile_length;
 int raw_height, raw_width, top_margin, left_margin;
 int height, width, fuji_width, colors, tiff_samples;
-int black, maximum, raw_color, use_gamma;
-int iheight, iwidth, shrink, flip, xmag, ymag;
+int black, maximum, mix_green, raw_color, use_gamma;
+int iheight, iwidth, shrink, flip;
+double pixel_aspect;
 int zero_after_ff, is_raw, dng_version, is_foveon;
 ushort (*image)[4], white[8][8], curve[0x1000], cr2_slice[3];
-float bright, user_mul[4], sigma_d, sigma_r;
-int four_color_rgb, document_mode, highlight;
+float bright, user_mul[4], threshold;
+int half_size, four_color_rgb, document_mode, highlight;
 int verbose, use_auto_wb, use_camera_wb;
 int output_color, output_bps, output_tiff;
-int fuji_layout, fuji_secondary, use_secondary;
+int fuji_layout, fuji_secondary, shot_select;
 float cam_mul[4], pre_mul[4], rgb_cam[3][4];	/* RGB from camera color */
 int histogram[4][0x2000];
 void (DCRaw::*write_thumb)(FILE *), (DCRaw::*write_fun)(FILE *);
@@ -89,6 +90,7 @@ int canon_600_color (int ratio[2], int mar);
 void canon_600_auto_wb();
 void canon_600_coeff();
 void canon_600_load_raw();
+void remove_zeroes();
 void canon_a5_load_raw();
 unsigned getbits (int nbits);
 void init_decoder();
@@ -103,6 +105,7 @@ void lossless_jpeg_load_raw();
 void adobe_copy_pixel (int row, int col, ushort **rp);
 void adobe_dng_load_raw_lj();
 void adobe_dng_load_raw_nc();
+void pentax_k10_load_raw();
 void nikon_compressed_load_raw();
 void nikon_load_raw();
 int nikon_is_compressed();
@@ -125,9 +128,11 @@ void phase_one_load_raw();
 unsigned ph1_bits (int nbits);
 void phase_one_load_raw_c();
 void leaf_hdr_load_raw();
+void sinar_4shot_load_raw();
 void imacon_full_load_raw();
 void packed_12_load_raw();
 void unpacked_load_raw();
+void panasonic_load_raw();
 void olympus_e300_load_raw();
 void olympus_cseries_load_raw();
 void minolta_rd175_load_raw();
@@ -172,16 +177,18 @@ void foveon_make_curves
 int foveon_apply_curve (short *curve, int i);
 void foveon_interpolate();
 void bad_pixels();
+void subtract(char *fname);
 void pseudoinverse (double (*in)[3], double (*out)[3], int size);
 void cam_xyz_coeff (double cam_xyz[4][3]);
 void colorcheck();
+void wavelet_denoise();
 void scale_colors();
+void pre_interpolate();
 void border_interpolate (int border);
 void lin_interpolate();
 void vng_interpolate();
 void cam_to_cielab (ushort cam[4], float lab[3]);
 void ahd_interpolate();
-void bilateral_filter();
 void recover_highlights();
 void tiff_get (unsigned base,
 	unsigned *tag, unsigned *type, unsigned *len, unsigned *save);
@@ -192,7 +199,7 @@ void parse_exif (int base);
 void romm_coeff (float romm_cam[3][3]);
 void parse_mos (int offset);
 void linear_table (unsigned len);
-int parse_tiff_ifd (int base, int level);
+int parse_tiff_ifd (int base);
 void parse_kodak_ifd (int base);
 void parse_tiff (int base);
 void parse_minolta (int base);
@@ -200,6 +207,7 @@ void parse_external_jpeg();
 void ciff_block_1030();
 void parse_ciff (int offset, int length);
 void parse_rollei();
+void parse_sinar_ia();
 void parse_phase_one (int base);
 void parse_fuji (int offset);
 int parse_jpeg (int offset);
@@ -214,10 +222,12 @@ void identify();
 void apply_profile (char *input, char *output);
 void convert_to_rgb();
 void fuji_rotate();
+void stretch();
 int flip_index (int row, int col);
 void gamma_lut (uchar lut[0x10000]);
 void tiff_set (ushort *ntag,
 	        ushort tag, ushort type, int count, int val);
+void tiff_head (struct tiff_hdr *th, int full);
 void write_ppm_tiff (FILE *ofp);
 void write_ppm (FILE *ofp);
 void write_ppm16 (FILE *ofp);
