@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * dcraw_api.cc - API for DCRaw
- * Copyright 2004-2006 by Udi Fuchs
+ * Copyright 2004-2007 by Udi Fuchs
  *
  * based on dcraw by Dave Coffin
  * http://www.cybercom.net/~dcoffin/
@@ -22,9 +22,11 @@
 #include <errno.h>
 #include <float.h>
 #include <glib.h>
+#include <glib/gi18n.h> /*For _(String) definition - NKBJ*/
 #include "dcraw_api.h"
 #include "dcraw.h"
 
+#define FORCC for (c=0; c < colors; c++)
 #define FC(filters,row,col) \
     (filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3)
 extern "C" {
@@ -58,15 +60,14 @@ int dcraw_open(dcraw_data *h,char *filename)
     d->lastStatus = DCRAW_SUCCESS;
     d->verbose = 1;
     d->ifname = g_strdup(filename);
-//    use_secondary = 0; /* for Fuji Super CCD SR */
     if (setjmp(d->failure)) {
-        d->dcraw_message(DCRAW_ERROR, "Fatal internal error\n");
+        d->dcraw_message(DCRAW_ERROR,_("Fatal internal error\n"));
         h->message = d->messageBuffer;
 	delete d;
         return DCRAW_ERROR;
     }
     if (!(d->ifp = fopen (d->ifname, "rb"))) {
-        d->dcraw_message(DCRAW_OPEN_ERROR, "Could not open %s: %s\n",
+        d->dcraw_message(DCRAW_OPEN_ERROR,_("Cannot open file %s: %s\n"),
                 filename, strerror(errno));
         g_free(d->ifname);
         h->message = d->messageBuffer;
@@ -77,7 +78,7 @@ int dcraw_open(dcraw_data *h,char *filename)
     /* We first check if dcraw recognizes the file, this is equivalent
      * to 'dcraw -i' succeeding */
     if (!d->make[0]) {
-	d->dcraw_message(DCRAW_OPEN_ERROR, "%s: unsupported file format.\n",
+	d->dcraw_message(DCRAW_OPEN_ERROR,_("%s: unsupported file format.\n"),
 		d->ifname);
         fclose(d->ifp);
         g_free(d->ifname);
@@ -88,7 +89,7 @@ int dcraw_open(dcraw_data *h,char *filename)
     }
     /* Next we check if dcraw can decode the file */
     if (!d->is_raw) {
-	d->dcraw_message(DCRAW_OPEN_ERROR, "Cannot decode %s\n", d->ifname);
+	d->dcraw_message(DCRAW_OPEN_ERROR,_("Cannot decode file %s\n"), d->ifname);
         fclose(d->ifp);
         g_free(d->ifname);
         h->message = d->messageBuffer;
@@ -113,7 +114,7 @@ int dcraw_open(dcraw_data *h,char *filename)
     h->filters = d->filters;
     h->raw_color = d->raw_color;
     h->shrink = d->shrink = (h->filters!=0);
-    h->ymag = d->ymag;
+    h->pixel_aspect = d->pixel_aspect;
     /* copied from dcraw's main() */
     switch ((d->flip+3600) % 360) {
         case 270: d->flip = 5; break;
@@ -162,7 +163,7 @@ int dcraw_load_raw(dcraw_data *h)
     }
     h->raw.colors = d->colors;
     h->fourColorFilters = d->filters;
-    d->dcraw_message(DCRAW_VERBOSE, "Loading %s %s image from %s...\n",
+    d->dcraw_message(DCRAW_VERBOSE,_("Loading %s %s image from %s ...\n"),
                 d->make, d->model, d->ifname);
     fseek (d->ifp, d->data_offset, SEEK_SET);
     (d->*d->load_raw)();
@@ -176,12 +177,13 @@ int dcraw_load_raw(dcraw_data *h)
     h->ifp = NULL;
     h->rgbMax = d->maximum;
     h->black = d->black;
-    d->dcraw_message(DCRAW_VERBOSE, "Black: %d, Maximum: %d\n",
+    d->dcraw_message(DCRAW_VERBOSE,_("Black: %d, Maximum: %d\n"),
 	    d->black, d->maximum);
     cam_to_cielab_INDI(NULL, NULL, h->colors, d->rgb_cam);
     dmin = DBL_MAX;
     for (i=0; i<h->colors; i++) if (dmin > d->pre_mul[i]) dmin = d->pre_mul[i];
     for (i=0; i<h->colors; i++) h->pre_mul[i] = d->pre_mul[i]/dmin;
+    if (h->colors==3) h->pre_mul[3] = 0;
     memcpy(h->cam_mul, d->cam_mul, sizeof d->cam_mul);
     memcpy(h->rgb_cam, d->rgb_cam, sizeof d->rgb_cam);
 
@@ -207,18 +209,17 @@ int dcraw_load_thumb(dcraw_data *h, dcraw_image_data *thumb)
     h->thumbOffset = d->thumb_offset;
     h->thumbBufferLength = d->thumb_length;
     if (d->thumb_offset==0) {
-	dcraw_message(d, DCRAW_ERROR,
-		"%s has no thumbnail.", d->ifname);
+	dcraw_message(d, DCRAW_ERROR,_("%s has no thumbnail."), d->ifname);
     } else if (d->thumb_load_raw!=NULL) {
 	dcraw_message(d, DCRAW_ERROR,
-		"Unsupported thumb format (load_raw) for %s", d->ifname);
+		_("Unsupported thumb format (load_raw) for %s"), d->ifname);
     } else if (d->write_thumb==&DCRaw::jpeg_thumb) {
 	h->thumbType = jpeg_thumb_type;
     } else if (d->write_thumb==&DCRaw::ppm_thumb) {
 	h->thumbType = ppm_thumb_type;
     } else {
 	dcraw_message(d, DCRAW_ERROR,
-		"Unsupported thumb format for %s", d->ifname);
+		_("Unsupported thumb format for %s"), d->ifname);
     }
     h->message = d->messageBuffer;
     return d->lastStatus;
@@ -341,23 +342,43 @@ int dcraw_image_resize(dcraw_image_data *image, int size)
     return DCRAW_SUCCESS;
 }
 
-/* Stretch image by 'ymag'. It is needed only for Nikon D1X images.
- * We can ignore 'xmag' since we always stretch before we flip */
-int dcraw_image_stretch(dcraw_image_data *image, int ymag)
+/* Adapted from dcraw.c stretch() - NKBJ */
+int dcraw_image_stretch(dcraw_image_data *image, double pixel_aspect)
 {
-    int r;
-    if (ymag==1) return DCRAW_SUCCESS;
-    if (ymag!=2) return DCRAW_ERROR;
-    int w = image->width;
-    dcraw_image_type *iBuf = g_new(dcraw_image_type,
-	    image->height * 2  * w);
-    for(r=0; r<image->height; r++) {
-	memcpy(iBuf[(2*r)*w], image->image[r*w], w*4*2);
-	memcpy(iBuf[(2*r+1)*w], image->image[r*w], w*4*2);
+    int newdim, row, col, c, colors = image->colors;
+    double rc, frac;
+    ushort *pix0, *pix1;
+    dcraw_image_type *iBuf;
+
+    if (pixel_aspect==1) return DCRAW_SUCCESS;
+    if (pixel_aspect < 1) {
+	newdim = (int)(image->height / pixel_aspect + 0.5);
+	iBuf = g_new(dcraw_image_type, image->width * newdim);
+	for (rc=row=0; row < newdim; row++, rc+=pixel_aspect) {
+	    frac = rc - (c = (int)rc);
+	    pix0 = pix1 = image->image[c*image->width];
+	    if (c+1 < image->height) pix1 += image->width*4;
+	    for (col=0; col < image->width; col++, pix0+=4, pix1+=4)
+		FORCC iBuf[row*image->width+col][c] =
+		    (guint16)(pix0[c]*(1-frac) + pix1[c]*frac + 0.5);
+	}
+	image->height = newdim;
+    } else {
+	newdim = (int)(image->width * pixel_aspect + 0.5);
+	iBuf = g_new(dcraw_image_type, image->height * newdim);
+	for (rc=col=0; col < newdim; col++, rc+=1/pixel_aspect) {
+	    frac = rc - (c = (int)rc);
+	    pix0 = pix1 = image->image[c];
+	    if (c+1 < image->width) pix1 += 4;
+	    for (row=0; row < image->height;
+		row++, pix0+=image->width*4, pix1+=image->width*4)
+		FORCC iBuf[row*newdim+col][c] =
+		    (guint16)(pix0[c]*(1-frac) + pix1[c]*frac + 0.5);
+	}
+	image->width = newdim;
     }
     g_free(image->image);
     image->image = iBuf;
-    image->height *= 2;
     return DCRAW_SUCCESS;
 }
 
@@ -490,4 +511,4 @@ void dcraw_message(void *dcraw, int code, char *format, ...)
     g_free(message);
 }
 
-}
+} /*extern "C"*/
