@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw.h - Common definitions for UFRaw.
- * Copyright 2004-2006 by Udi Fuchs
+ * Copyright 2004-2007 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -50,6 +50,9 @@ enum { in_profile, out_profile, profile_types};
 enum { raw_expander, live_expander, expander_count };
 enum { ppm8_type, ppm16_type, tiff8_type, tiff16_type, jpeg_type,
        embedded_jpeg_type, embedded_png_type };
+enum { clip_details, restore_lch_details, restore_hsv_details,
+       restore_types };
+enum { digital_highlights, film_highlights, highlights_types };
 
 typedef struct {
     char *make;
@@ -61,8 +64,8 @@ typedef struct {
 
 typedef struct {
     unsigned rgbMax, max, exposure, colors, useMatrix;
-    gboolean unclip;
-    int rgbWB[4], rgbNorm[4], colorMatrix[3][4];
+    int restoreDetails, clipHighlights;
+    int rgbWB[4], colorMatrix[3][4];
     double gamma, linear;
     char profileFile[2][max_path];
     void *profile[2];
@@ -126,7 +129,8 @@ typedef struct {
     double temperature, green;
     double chanMul[4];
     double exposure, saturation, black; /* black is only used in CMD */
-    gboolean unclip;
+    int ExposureNorm;
+    int restoreDetails, clipHighlights;
     int autoExposure, autoBlack;
     int BaseCurveIndex, BaseCurveCount;
     CurveData BaseCurve[max_curves];
@@ -177,6 +181,7 @@ typedef struct {
 typedef struct ufraw_struct {
     char filename[max_path];
     int predictedHeight, predictedWidth, rgbMax, colors, raw_color, useMatrix;
+    gboolean LoadingID; /* Indication that we are loading an ID file */
     float rgb_cam[3][4];
     image_data image;
     image_data thumb;
@@ -251,10 +256,9 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc);
 developer_data *developer_init();
 void developer_destroy(developer_data *d);
 void developer_profile(developer_data *d, int type, profile_data *p);
-void developer_prepare(developer_data *d, int rgbMax, double exposure,
-    int unclip, double chanMul[4], float rgb_cam[3][4], int colors,
-    int useMatrix, profile_data *in, profile_data *out, int intent,
-    double saturation, CurveData *baseCurve, CurveData *curve);
+void developer_prepare(developer_data *d, conf_data *conf,
+    int rgbMax, float rgb_cam[3][4], int colors, int useMatrix,
+    gboolean autoTools);
 void develope(void *po, guint16 pix[4], developer_data *d, int mode,
     guint16 *buf, int count);
 
@@ -273,6 +277,9 @@ int ufraw_write_embedded(ufraw_data *uf);
 /* prototype for functions in ufraw_chooser.c */
 void ufraw_chooser(conf_data *conf, char *defPath);
 
+/* prototype for functions in ufraw_icons.c */
+void ufraw_icons_init();
+
 /* prototype for functions in ufraw_exif.c */
 int ufraw_exif_from_raw(ufraw_data *uf);
 
