@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw_conf.c - handle configuration issues
- * Copyright 2004-2006 by Udi Fuchs
+ * Copyright 2004-2007 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -32,7 +32,9 @@ const conf_data conf_default = {
     6500, 1.0, /* temperature, green */
     { -1.0, -1.0, -1.0, -1.0 }, /* chanMul[] */
     0.0, 1.0, 0.0, /* exposure, saturation, black */
-    TRUE /* Unclip highlights */,
+    0, /* ExposureNorm */
+    restore_lch_details, /* restoreDetails */
+    digital_highlights, /* clipHighlights */
     disabled_state, /* autoExposure */
     disabled_state, /* autoBlack */
     camera_curve, camera_curve+1, /* BaseCurveIndex, BaseCurveCount */
@@ -68,7 +70,7 @@ const conf_data conf_default = {
     ppm8_type, 85, no_id, /* type, compression, createID */
     TRUE, /* embedExif */
     1, 0, /* shrink, size */
-    FALSE, /* overwrite exsisting files without asking */
+    FALSE, /* overwrite existing files without asking */
     FALSE, /* losslessCompress */
     FALSE, /* load embedded preview image */
 
@@ -93,15 +95,19 @@ const conf_data conf_default = {
 };
 
 const char *interpolationNames[] =
-    { "ahd", "vng", "four-color", "bilinear", "half" };
+    { "ahd", "vng", "four-color", "bilinear", "half", NULL };
+const char *restoreDetailsNames[] =
+    { "clip", "lch", "hsv", NULL };
+const char *clipHighlightsNames[] =
+    { "digital", "film", NULL };
 
-int conf_find_name(const char name[],const char *namesList[])
+int conf_find_name(const char name[],const char *namesList[], int notFound)
 {
     int i;
     for (i=0; namesList[i]!=NULL; i++) {
 	if (!strcmp(name, namesList[i])) return i;
     }
-    return -1;	
+    return notFound;
 }
 
 const char *conf_get_name(const char *namesList[], int index)
@@ -386,8 +392,8 @@ void conf_parse_text(GMarkupParseContext *context, const gchar *text, gsize len,
 		default: c->interpolation = ahd_interpolation;
 	    }
 	} else {
-	    c->interpolation = conf_find_name(temp, interpolationNames);
-	    if (c->interpolation<0) c->interpolation = ahd_interpolation;
+	    c->interpolation = conf_find_name(temp, interpolationNames,
+		    conf_default.interpolation);
 	}
     }
     if (!strcmp("RawExpander", element))
@@ -434,8 +440,21 @@ void conf_parse_text(GMarkupParseContext *context, const gchar *text, gsize len,
 	if (i<4) c->chanMul[3] = 0.0;
     }
     if (!strcmp("Exposure", element)) sscanf(temp, "%lf", &c->exposure);
+    if (!strcmp("ExposureNorm", element)) sscanf(temp, "%d", &c->ExposureNorm);
     if (!strcmp("Saturation", element)) sscanf(temp, "%lf", &c->saturation);
-    if (!strcmp("Unclip", element)) sscanf(temp, "%d", &c->unclip);
+    if (!strcmp("RestoreDetails", element))
+	c->restoreDetails = conf_find_name(temp, restoreDetailsNames,
+		conf_default.restoreDetails);
+    if (!strcmp("ClipHighlights", element))
+	c->clipHighlights = conf_find_name(temp, clipHighlightsNames,
+		conf_default.clipHighlights);
+    /* For compatibility with UFRaw-0.10 and earlier. */
+    if (!strcmp("Unclip", element)) {
+	int unclip;
+	sscanf(temp, "%d", &unclip);
+	if (unclip) c->restoreDetails = restore_lch_details;
+	else c->restoreDetails = clip_details;
+    }
     if (!strcmp("AutoExposure", element)) sscanf(temp, "%d", &c->autoExposure);
     if (!strcmp("AutoBlack", element)) sscanf(temp, "%d", &c->autoBlack);
     if (!strcmp("CurvePath", element)) {
@@ -658,8 +677,15 @@ int conf_save(conf_data *c, char *IDFilename, char **confBuffer)
     }
     if (c->exposure!=conf_default.exposure)
         buf = uf_markup_buf(buf, "<Exposure>%lf</Exposure>\n", c->exposure);
-    if (c->unclip!=conf_default.unclip)
-        buf = uf_markup_buf(buf, "<Unclip>%d</Unclip>\n", c->unclip);
+    if (c->ExposureNorm!=conf_default.ExposureNorm)
+        buf = uf_markup_buf(buf, "<ExposureNorm>%d</ExposureNorm>\n",
+		c->ExposureNorm);
+    if (c->restoreDetails!=conf_default.restoreDetails)
+        buf = uf_markup_buf(buf, "<RestoreDetails>%s</RestoreDetails>\n",
+		conf_get_name(restoreDetailsNames, c->restoreDetails));
+    if (c->clipHighlights!=conf_default.clipHighlights)
+        buf = uf_markup_buf(buf, "<ClipHighlights>%s</ClipHighlights>\n",
+		conf_get_name(clipHighlightsNames, c->clipHighlights));
     if (c->autoExposure!=conf_default.autoExposure)
         buf = uf_markup_buf(buf,
 		"<AutoExposure>%d</AutoExposure>\n", c->autoExposure);
@@ -886,11 +912,13 @@ void conf_copy_image(conf_data *dst, const conf_data *src)
     g_strlcpy(dst->make, src->make, max_name);
     g_strlcpy(dst->model, src->model, max_name);
     dst->exposure = src->exposure;
+    dst->ExposureNorm = src->ExposureNorm;
     dst->saturation = src->saturation;
     dst->black = src->black;
     dst->autoExposure = src->autoExposure;
     dst->autoBlack = src->autoBlack;
-    dst->unclip = src->unclip;
+    dst->restoreDetails = src->restoreDetails;
+    dst->clipHighlights = src->clipHighlights;
     g_strlcpy(dst->darkframeFile, src->darkframeFile, max_path);
     /* We only copy the current BaseCurve */
     if (src->BaseCurveIndex<=camera_curve) {
@@ -996,7 +1024,10 @@ void conf_copy_save(conf_data *dst, const conf_data *src)
 int conf_set_cmd(conf_data *conf, const conf_data *cmd)
 {
     if (cmd->overwrite!=-1) conf->overwrite = cmd->overwrite;
-    if (cmd->unclip!=-1) conf->unclip = cmd->unclip;
+    if (cmd->restoreDetails!=-1)
+	conf->restoreDetails = cmd->restoreDetails;
+    if (cmd->clipHighlights!=-1)
+	conf->clipHighlights = cmd->clipHighlights;
     if (cmd->losslessCompress!=-1)
 	conf->losslessCompress = cmd->losslessCompress;
     if (cmd->embedExif!=-1) conf->embedExif = cmd->embedExif;
@@ -1068,8 +1099,6 @@ int conf_set_cmd(conf_data *conf, const conf_data *cmd)
 /* Following are global strings and functions used by both 'ufraw' and
  * 'ufraw-batch'. ufraw_conf.c is a good home for them since they are
  * closely related to the other configuration functions. */
-
-
 char *helpText[] = {
 N_("UFRaw "), VERSION, N_(" - Unidentified Flying Raw converter for digital camera images.\n"),
 "\n",
@@ -1083,7 +1112,7 @@ N_("By default 'ufraw' displays a preview window for each raw image allowing\n"
 "To process the images with no questions asked (and no preview) use\n"
 "'ufraw-batch'.\n"),
 "\n",
-N_("The input files can be either raw images or ufraw's ID files. ID file\n"
+N_("The input files can be either raw images or ufraw's ID files. ID files\n"
 "contain a raw image filename and the parameters for handling the image.\n"
 "One can also use an ID file with the option:\n"),
 "\n",
@@ -1098,7 +1127,7 @@ N_("--green=GREEN         Green color normalization.\n"),
 N_("--base-curve=manual|linear|camera|custom|CURVE\n"
 "                      Type of base tone curve to use. CURVE can be any\n"
 "                      curve that was previously loaded in the GUI.\n"
-"                      (default camera if such exsists, linear otherwise).\n"),
+"                      (default camera if such exists, linear otherwise).\n"),
 N_("--base-curve-file=file\n"
 "                      Use base tone curve included in specified file.\n"
 "                      Overrides --base-curve option.\n"),
@@ -1108,7 +1137,15 @@ N_("--curve=manual|linear|CURVE\n"
 "                      (default linear).\n"),
 N_("--curve-file=file     Use luminosity curve included in specified file.\n"
 "                      Overrides --curve option.\n"),
-N_("--[un]clip            Unclip [clip] highlights (default clip).\n"),
+N_("--restore=clip|lch|hsv\n"
+   "                      Restore details for negative EV.\n"
+   "                      'clip' restores nothing - safe from artifacts.\n"
+   "                      'lch' restores in LCH space - giving soft details.\n"
+   "                      'hsv' restores in HSV space - giving sharp details.\n"
+   "                      (default lch).\n"),
+N_("--clip=digital|film   Clip highlights for positive EV.\n"
+   "                      'digital' linear digital sensor response.\n"
+   "                      'film' emulate soft film response. (default digital).\n"),
 N_("--gamma=GAMMA         Gamma adjustment of the base curve (default 0.45).\n"),
 N_("--linearity=LINEARITY Linearity of the base curve (default 0.10).\n"),
 N_("--saturation=SAT      Saturation adjustment (default 1.0, 0 for B&W output).\n"),
@@ -1128,7 +1165,7 @@ N_("--out-type=ppm8|ppm16|tiff8|tiff16|jpeg\n"
 N_("--create-id=no|also|only\n"
 "                      Create no|also|only ID file (default no).\n"),
 N_("--compression=VALUE   JPEG compression (0-100, default 85).\n"),
-N_("--[no]exif            Embed exif in output JPEG (default embed exif).\n"),
+N_("--[no]exif            Embed EXIF in output JPEG (default embed EXIF).\n"),
 N_("--[no]zip             Enable [disable] TIFF zip compression (default nozip).\n"),
 N_("--embedded-image      Extract the preview image embedded in the raw file\n"
 "                      instead of converting the raw image.\n"),
@@ -1136,6 +1173,7 @@ N_("--out-path=PATH       PATH for output file (default use input file's path).\
 N_("--output=FILE         Output file name, use '-' to output to stdout.\n"),
 N_("--darkframe=FILE      Use FILE for raw darkframe subtraction.\n"),
 N_("--overwrite           Overwrite existing files without asking (default no).\n"),
+N_("--silent              Do not display any messages during batch conversion.\n"),
 "\n",
 N_("UFRaw first reads the setting from the resource file $HOME/.ufrawrc.\n"
 "Then, if an ID file is specified it setting are read. Next, the setting from\n"
@@ -1200,7 +1238,8 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
     char *baseCurveName=NULL, *baseCurveFile=NULL,
 	 *curveName=NULL, *curveFile=NULL, *outTypeName=NULL,
          *createIDName=NULL, *outPath=NULL, *output=NULL, *conf=NULL,
-         *interpolationName=NULL, *darkframeFile=NULL;
+         *interpolationName=NULL, *darkframeFile=NULL,
+	 *restoreName=NULL, *clipName=NULL;
     static struct option options[] = {
         {"wb", 1, 0, 'w'},
         {"temperature", 1, 0, 't'},
@@ -1223,10 +1262,10 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
         {"out-path", 1, 0, 'p'},
         {"output", 1, 0, 'o'},
         {"darkframe",1,0,'a'},
+        {"restore", 0, 0, 'r'},
+        {"clip", 0, 0, 'u'},
         {"conf", 1, 0, 'C'},
 /* Binary flags that don't have a value are here at the end */
-        {"unclip", 0, 0, 'u'},
-        {"clip", 0, 0, 'U'},
         {"zip", 0, 0, 'z'},
         {"nozip", 0, 0, 'Z'},
         {"overwrite", 0, 0, 'O'},
@@ -1245,10 +1284,10 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
 	&cmd->saturation,
         &cmd->exposure, &cmd->black, &interpolationName,
 	&cmd->shrink, &cmd->size, &cmd->compression,
-	&outTypeName, &createIDName, &outPath, &output, &darkframeFile, &conf };
+	&outTypeName, &createIDName, &outPath, &output, &darkframeFile,
+	&restoreName, &clipName, &conf };
     cmd->autoExposure = disabled_state;
     cmd->autoBlack = disabled_state;
-    cmd->unclip=-1;
     cmd->losslessCompress=-1;
     cmd->overwrite=-1;
     cmd->embedExif=-1;
@@ -1314,10 +1353,10 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
         case 'o':
         case 'a':
         case 'C':
+        case 'r':
+        case 'u':
             *(char **)optPointer[index] = optarg;
             break;
-        case 'u': cmd->unclip = TRUE; break;
-        case 'U': cmd->unclip = FALSE; break;
         case 'O': cmd->overwrite = TRUE; break;
 	case 'm': cmd->embeddedImage = TRUE; break;
 	case 'q': cmd->silent = TRUE; break;
@@ -1350,8 +1389,8 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
         case '?': /* invalid option. Warning printed by getopt() */
             return -1;
         default:
-            ufraw_message(UFRAW_ERROR, "getopt returned "
-                       "character code 0%o ??", c);
+            ufraw_message(UFRAW_ERROR, _("getopt returned "
+                       "character code 0%o ??"), c);
             return -1;
         }
     }
@@ -1452,7 +1491,7 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
         else if (!strcmp(interpolationName, "quick"))
             cmd->interpolation = bilinear_interpolation;
 	else cmd->interpolation = conf_find_name(interpolationName,
-		    interpolationNames);
+		    interpolationNames, -1);
 	if (cmd->interpolation<0 || cmd->interpolation==half_interpolation) {
             ufraw_message(UFRAW_ERROR,
                 _("'%s' is not a valid interpolation option."),
@@ -1460,6 +1499,26 @@ int ufraw_process_args(int *argc, char ***argv, conf_data *cmd, conf_data *rc)
             return -1;
         }
     }
+    cmd->restoreDetails = -1;
+    if (restoreName!=NULL) {
+	cmd->restoreDetails = conf_find_name(restoreName,
+		    restoreDetailsNames, -1);
+	if ( cmd->restoreDetails<0 ) {
+            ufraw_message(UFRAW_ERROR, _("'%s' is not a valid restore option."),
+                restoreName);
+            return -1;
+	}
+    }
+    cmd->clipHighlights = -1;
+    if (clipName!=NULL) {
+	cmd->clipHighlights = conf_find_name(clipName,
+		    clipHighlightsNames, -1);
+	if ( cmd->clipHighlights<0 ) {
+            ufraw_message(UFRAW_ERROR, _("'%s' is not a valid clip option."),
+                clipName);
+            return -1;
+	}
+    }
     if (cmd->shrink!=NULLF && cmd->size!=NULLF) {
         ufraw_message(UFRAW_ERROR,
                         _("you can not specify both --shrink and --size"));
