@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw_routines.c - general routines
- * Copyright 2004-2006 by Udi Fuchs
+ * Copyright 2004-2007 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -104,7 +104,11 @@ char *uf_file_set_absolute(const char *filename)
 	char *path = g_path_get_dirname(filename);
 	char *base = g_path_get_basename(filename);
 	char *canon = canonicalize_file_name(path);
-	char *abs = g_build_filename(canon, base, NULL);
+	char *abs;
+	if ( canon==NULL )
+	    abs = g_strdup(filename);
+	else
+	    abs = g_build_filename(canon, base, NULL);
 	g_free(path);
 	g_free(base);
 	g_free(canon);
@@ -138,8 +142,9 @@ char *uf_markup_buf(char *buffer, const char *format, ...)
     }
 }
 
-const char raw_ext[]= "arw,bay,bmq,cr2,crw,cs1,dc2,dcr,dng,erf,fff,hdr,jpg,k25,"
-	"kdc,mdc,mos,mrw,nef,orf,pef,pxn,raf,raw,rdc,sr2,srf,sti,tif,ufraw,x3f";
+const char raw_ext[]= "arw,bay,bmq,cr2,crw,cs1,dc2,dcr,dng,erf,fff,hdr,ia,jpg,"
+	"k25,kc2,kdc,mdc,mos,mrw,nef,orf,pef,pxn,raf,raw,rdc,sr2,srf,sti,tif,"
+	"ufraw,x3f";
 
 const char *file_type[] = { ".ppm", ".ppm", ".tif", ".tif", ".jpg",
 	".embedded.jpg", ".embedded.png" };
@@ -156,7 +161,7 @@ char *uf_set_locale_C()
 	    return locale;
 	} else {
 	    setlocale(LC_NUMERIC, locale);
-	    ufraw_message(UFRAW_ERROR, "Fatal error setting C locale");
+	    ufraw_message(UFRAW_ERROR, _("Fatal error setting C locale"));
 	    return NULL;
 	}
     } else {
@@ -185,6 +190,7 @@ double profile_default_gamma(profile_data *p)
 	    || !strncmp(p->productName, "Nikon D1 for NEF", 16)
 	    || !strncmp(p->productName, "Nikon D50 for NEF", 17)
 	    || !strncmp(p->productName, "Nikon D70 for NEF", 17)
+	    || !strncmp(p->productName, "Nikon D80 for NEF", 17)
 	    || !strncmp(p->productName, "Nikon D100 for NEF", 18) )
 	return 0.45;
     else
