@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw_ufraw.c - program interface to all the components
- * Copyright 2004-2006 by Udi Fuchs
+ * Copyright 2004-2007 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -201,8 +201,14 @@ ufraw_data *ufraw_open(char *filename)
         uf->predictedWidth = raw->fuji_width / raw->fuji_step;
         uf->predictedHeight = (raw->height - raw->fuji_width) / raw->fuji_step;
     } else {
-        uf->predictedHeight = raw->height * raw->ymag;
-        uf->predictedWidth = raw->width;
+	if (raw->pixel_aspect < 1)
+	    uf->predictedHeight = raw->height / raw->pixel_aspect + 0.5;
+	else
+	    uf->predictedHeight = raw->height;
+	if (raw->pixel_aspect > 1)
+	    uf->predictedWidth = raw->width * raw->pixel_aspect + 0.5;
+	else
+	    uf->predictedWidth = raw->width;
     }
     if (raw->flip & 4) {
         int tmp = uf->predictedHeight;
@@ -245,7 +251,6 @@ ufraw_data *ufraw_load_darkframe(char *darkframeFile)
 int ufraw_config(ufraw_data *uf, conf_data *rc, conf_data *conf, conf_data *cmd)
 {
     int status;
-    gboolean loadingID = FALSE;
 
     if (strcmp(rc->wb, spot_wb)) rc->chanMul[0] = -1.0;
     if (rc->autoExposure==enabled_state) rc->autoExposure = apply_state;
@@ -253,11 +258,13 @@ int ufraw_config(ufraw_data *uf, conf_data *rc, conf_data *conf, conf_data *cmd)
 
     /* Check if we are loading an ID file */
     if (uf!=NULL) {
+	uf->LoadingID = FALSE;
 	if (uf->conf!=NULL) {
-	    loadingID = TRUE;
+	    uf->LoadingID = TRUE;
 	    conf_data tmp = *rc;
 	    conf_copy_image(&tmp, uf->conf);
 	    conf_copy_save(&tmp, uf->conf);
+	    g_strlcpy(tmp.outputFilename, uf->conf->outputFilename, max_path);
 	    g_strlcpy(tmp.outputPath, uf->conf->outputPath, max_path);
 	    *uf->conf = tmp;
 	} else {
@@ -283,20 +290,27 @@ int ufraw_config(ufraw_data *uf, conf_data *rc, conf_data *conf, conf_data *cmd)
     char *absname = uf_file_set_absolute(uf->filename);
     g_strlcpy(uf->conf->inputFilename, absname, max_path);
     g_free(absname);
-    if (!loadingID) {
+    if (!uf->LoadingID) {
 	g_snprintf(uf->conf->inputURI, max_path, "file://%s",
 		uf->conf->inputFilename);
 	struct stat s;
 	fstat(fileno(raw->ifp), &s);
 	g_snprintf(uf->conf->inputModTime, max_name, "%d", (int)s.st_mtime);
     }
+    /*Reset EXIF data text fields to avoid spill over between images.*/
+    strcpy(uf->conf->isoText, "");
+    strcpy(uf->conf->shutterText, "");
+    strcpy(uf->conf->apertureText, "");
+    strcpy(uf->conf->focalLenText, "");
+    strcpy(uf->conf->focalLen35Text, "");
+    strcpy(uf->conf->lensText, "");
     if (ufraw_exif_from_raw(uf)!=UFRAW_SUCCESS) {
         ufraw_message(UFRAW_SET_LOG, "Error reading EXIF data from %s\n",
                 uf->filename);
     }
     /* If we switched cameras, ignore channel multipliers and
      * change spot_wb to manual_wb */
-    if ( !loadingID &&
+    if ( !uf->LoadingID &&
 	 ( strcmp(uf->conf->make, raw->make)!=0 ||
 	   strcmp(uf->conf->model, raw->model)!=0 ) ) {
 	uf->conf->chanMul[0] = -1.0;
@@ -455,7 +469,45 @@ int ufraw_load_raw(ufraw_data *uf)
         ufraw_substract_darkframe(uf);
     memcpy(uf->rgb_cam, raw->rgb_cam, sizeof uf->rgb_cam);
 
+    /* Canon EOS cameras require special exposure normalization */
+    if ( strcmp(uf->conf->make, "Canon")==0 &&
+	 strncmp(uf->conf->model, "EOS", 3)==0 ) {
+	int c, max = raw->cam_mul[0];
+	for (c=1; c<raw->colors; c++) max = MAX(raw->cam_mul[c], max);
+	/* Camera multipliers in DNG file are normalized to 1.
+	 * Therefore, they can not be used to normalize exposure.
+	 * Also, for some Canon DSLR cameras dcraw cannot read the
+	 * camera multipliers (1D for example). */
+	if ( max < 100 ) {
+	    uf->conf->ExposureNorm = 0;
+	    ufraw_message(UFRAW_SET_LOG, "Failed to normalizing exposure\n");
+	} else {
+	    /* Convert exposure value from old ID files from before
+	     * ExposureNorm */
+	    if (uf->LoadingID && uf->conf->ExposureNorm==0)
+		uf->conf->exposure -= log(1.0*uf->rgbMax/max)/log(2);
+	    uf->conf->ExposureNorm = max;
+	    ufraw_message(UFRAW_SET_LOG,
+		    "Exposure Normalization set to %d (%.2f EV)\n",
+		    uf->conf->ExposureNorm,
+		    log(1.0*uf->rgbMax/uf->conf->ExposureNorm)/log(2));
+	}
+    } else {
+	uf->conf->ExposureNorm = 0;
+    }
+    /* chanMul[0]<0 signals that we need to recalculate the WB */
     if (uf->conf->chanMul[0]<0) ufraw_set_wb(uf);
+    else {
+	/* Otherwise we just normalize the channels and recalculate
+	 * the temperature/green */
+	int WBTuning = uf->conf->WBTuning;
+	char wb[max_name];
+	g_strlcpy(wb, uf->conf->wb, max_name);
+	g_strlcpy(uf->conf->wb, spot_wb, max_name);
+	ufraw_set_wb(uf);
+	g_strlcpy(uf->conf->wb, wb, max_name);
+	uf->conf->WBTuning = WBTuning;
+    }
     ufraw_auto_expose(uf);
     ufraw_auto_black(uf);
     return UFRAW_SUCCESS;
@@ -481,28 +533,22 @@ int ufraw_convert_image(ufraw_data *uf)
     dcraw_image_data final;
     int shrink = 1;
 
-//    preview_progress(uf->widget, "Loading image", 0.1);
-    developer_prepare(uf->developer, uf->rgbMax,
-	    pow(2,uf->conf->exposure), uf->conf->unclip,
-	    uf->conf->chanMul, uf->rgb_cam, uf->colors, uf->useMatrix,
-	    &uf->conf->profile[0][uf->conf->profileIndex[0]],
-	    &uf->conf->profile[1][uf->conf->profileIndex[1]], uf->conf->intent,
-	    uf->conf->saturation,
-	    &uf->conf->BaseCurve[uf->conf->BaseCurveIndex],
-	    &uf->conf->curve[uf->conf->curveIndex]);
+//    preview_progress(uf->widget, _("Loading image"), 0.1);
+    developer_prepare(uf->developer, uf->conf,
+	    uf->rgbMax, uf->rgb_cam, uf->colors, uf->useMatrix, FALSE);
     /* We can do a simple interpolation in the following cases:
      * We shrink by an integer value.
-     * If there is a ymag (D1X) shrink must be at least 4.
+     * If pixel_aspect<1 (e.g. NIKON D1X) shrink must be at least 4.
      * Wanted size is smaller than raw size (size is after a raw->shrink).
      * There are no filters (Foveon). */
     if ( uf->conf->interpolation==half_interpolation ||
-         ( uf->conf->size==0 && uf->conf->shrink/raw->ymag>1 ) ||
+         ( uf->conf->size==0 && uf->conf->shrink>1 ) ||
          ( uf->conf->size>0 &&
-	   uf->conf->size<MAX(raw->raw.height, raw->raw.width) ) ||
-	 ( raw->filters==0 )  ) {
-	if (uf->conf->size==0 && uf->conf->shrink>=2 &&
-		uf->conf->shrink%raw->ymag==0)
-	    shrink = uf->conf->shrink / raw->ymag;
+	   uf->conf->size<=MAX(raw->raw.height, raw->raw.width) ) ||
+	 ( raw->filters==0 ) ) {
+	if (uf->conf->size==0 && uf->conf->shrink>1 &&
+		(int)(uf->conf->shrink*raw->pixel_aspect)%2==0)
+	    shrink = uf->conf->shrink * raw->pixel_aspect;
 	else if (uf->conf->interpolation==half_interpolation)
 	    shrink = 2;
 	else if (raw->filters!=0)
@@ -522,12 +568,10 @@ int ufraw_convert_image(ufraw_data *uf)
 	g_free(uf->image.image);
         uf->image.image = final.image;
     }
-    if (raw->ymag==2) {
-	dcraw_image_stretch(&final, raw->ymag);
-	if (uf->conf->size==0 && uf->conf->shrink>1)
-            dcraw_image_resize(&final,
-		    shrink*MAX(final.height, final.width)/uf->conf->shrink);
-    }
+    dcraw_image_stretch(&final, raw->pixel_aspect);
+    if (uf->conf->size==0 && uf->conf->shrink>1)
+	dcraw_image_resize(&final,
+		shrink*MAX(final.height, final.width)/uf->conf->shrink);
     if (uf->conf->size>0) {
         if ( uf->conf->size>MAX(final.height, final.width) ) {
             ufraw_message(UFRAW_ERROR, _("Can not downsize from %d to %d."),
@@ -536,12 +580,12 @@ int ufraw_convert_image(ufraw_data *uf)
             dcraw_image_resize(&final, uf->conf->size);
 	}
     }
-//    preview_progress(uf->widget, "Loading image", 0.4);
+//    preview_progress(uf->widget, _("Loading image"), 0.4);
     uf->image.image = final.image;
     dcraw_flip_image(&final, raw->flip);
     uf->image.height = final.height;
     uf->image.width = final.width;
-//    preview_progress(uf->widget, "Loading image", 0.5);
+//    preview_progress(uf->widget, _("Loading image"), 0.5);
     return UFRAW_SUCCESS;
 }
 
@@ -780,15 +824,12 @@ void ufraw_auto_expose(ufraw_data *uf)
     if (uf->conf->autoExposure!=apply_state) return;
 
     /* Reset the exposure and luminosityCurve */
-    developer_prepare(uf->developer, uf->rgbMax,
-	    pow(2,0) /*exposure*/, uf->conf->unclip,
-	    uf->conf->chanMul, uf->rgb_cam, uf->colors, uf->useMatrix,
-	    &uf->conf->profile[0][uf->conf->profileIndex[0]],
-	    &uf->conf->profile[1][uf->conf->profileIndex[1]],
-	    uf->conf->intent,
-	    uf->conf->saturation,
-	    &uf->conf->BaseCurve[uf->conf->BaseCurveIndex],
-	    NULL /*luminosityCurve*/);
+    uf->conf->exposure = 0;
+    /* If we normalize the exposure then 0 EV also gets normalized */
+    if ( uf->conf->ExposureNorm>0 )
+	uf->conf->exposure = -log(1.0*uf->rgbMax/uf->conf->ExposureNorm)/log(2);
+    developer_prepare(uf->developer, uf->conf,
+	    uf->rgbMax, uf->rgb_cam, uf->colors, uf->useMatrix, TRUE);
     /* Find the grey value that gives 99% luminosity */
     double maxChan = 0;
     for (c=0; c<uf->colors; c++) maxChan = MAX(uf->conf->chanMul[c], maxChan);
@@ -809,6 +850,11 @@ void ufraw_auto_expose(ufraw_data *uf)
                 sum += uf->RawLumHistogram[wp];
     /* Set 99% of the luminosity values with luminosity below 99% */
     uf->conf->exposure = log((double)p/wp)/log(2);
+    /* If we are going to normalize the exposure later,
+     * we need to cancel its effect here. */
+    if ( uf->conf->ExposureNorm>0 )
+	uf->conf->exposure -=
+		log(1.0*uf->rgbMax/uf->conf->ExposureNorm)/log(2);
     uf->conf->autoExposure = enabled_state;
 //    ufraw_message(UFRAW_SET_LOG, "ufraw_auto_expose: "
 //	    "Exposure %f (white point %d/%d)\n", uf->conf->exposure, wp, p);
@@ -823,15 +869,8 @@ void ufraw_auto_black(ufraw_data *uf)
     if (uf->conf->autoBlack==disabled_state) return;
 
     /* Reset the luminosityCurve */
-    developer_prepare(uf->developer, uf->rgbMax,
-	    pow(2,uf->conf->exposure), uf->conf->unclip,
-	    uf->conf->chanMul, uf->rgb_cam, uf->colors, uf->useMatrix,
-	    &uf->conf->profile[0][uf->conf->profileIndex[0]],
-	    &uf->conf->profile[1][uf->conf->profileIndex[1]],
-	    uf->conf->intent,
-	    uf->conf->saturation,
-	    &uf->conf->BaseCurve[uf->conf->BaseCurveIndex],
-	    NULL /*luminosityCurve*/);
+    developer_prepare(uf->developer, uf->conf,
+	    uf->rgbMax, uf->rgb_cam, uf->colors, uf->useMatrix, TRUE);
     /* Calculate the black point */
     ufraw_build_raw_luminosity_histogram(uf);
     stop = uf->RawLumCount/256/4;
@@ -865,15 +904,8 @@ void ufraw_auto_curve(ufraw_data *uf)
     double norm = (1-pow(decay,steps))/(1-decay);
 
     CurveDataReset(curve);
-    developer_prepare(uf->developer, uf->rgbMax,
-	    pow(2,uf->conf->exposure), uf->conf->unclip,
-	    uf->conf->chanMul, uf->rgb_cam, uf->colors, uf->useMatrix,
-	    &uf->conf->profile[0][uf->conf->profileIndex[0]],
-	    &uf->conf->profile[1][uf->conf->profileIndex[1]],
-	    uf->conf->intent,
-	    uf->conf->saturation,
-	    &uf->conf->BaseCurve[uf->conf->BaseCurveIndex],
-	    NULL /*luminosityCurve*/);
+    developer_prepare(uf->developer, uf->conf,
+	    uf->rgbMax, uf->rgb_cam, uf->colors, uf->useMatrix, TRUE);
     /* Calculate curve points */
     ufraw_build_raw_luminosity_histogram(uf);
     stop = uf->RawLumCount/256/4;
